/*
	Customise Grid Control UI to Provide Better Feedback
	and
	Sort Grid Control Alphabetically.
	By Adrian Paech: 23/09/2016
*/

$(window).load(function () {
    if (document.URL.indexOf("ServiceCatalog/RequestOffering") === -1) { //Only worry about request offering forms
        return; 
    }
    
    //Get all objects that hold our kendo grids.
    var divGridControls = $("div[data-control=checkboxGridByCriteriaOld");

    for (var i = 0; i < divGridControls.length; i++) {        
        //Re-get this element as an object.
        var thisKendoGrid = $(divGridControls[i]).getKendoGrid();
				
		var kendoGridIndex = i;
		thisKendoGrid.kendoGridIndex = kendoGridIndex;
		
		/*Track if Grid is configured for 'Multi-Select'*/
		var isMultiSelect = divGridControls[i].getAttribute("data-control-ismultiselect").toLowerCase().trim();
		if (isMultiSelect == "true") {
			thisKendoGrid.isMultiSelect = true;
		}
		else {
			thisKendoGrid.isMultiSelect = false;
		}
		
		/* Keep track of multiple Selected Items in a separate array
		This is required as 'thisEventKendoGrid.select()' only returns the last selected item, not all items 
		Am unsure why this occurs */ 
		if (thisKendoGrid.isMultiSelect) {
			thisKendoGrid.selectedItems = new Array();
		}
		
		//Add Selection Summary Footer
		var selectSummary_html = "<span id='gridSelectSummary" + kendoGridIndex + "' class='gridSelectSummary'></span>";
		thisKendoGrid.wrapper.find(".k-pager-info").parent().before(selectSummary_html);
		//Pre-set label with 'Empty'
		var selectSummary = "<div class='gridSelectSummary-label'>Selection:</div><div class='gridSelectSummary-label'><i><font color=gray>Empty</font></i></div>";	
		$("#gridSelectSummary" + kendoGridIndex).html(selectSummary);
		
		//Bind 'Change' event whenever a Grid item is selected.
		thisKendoGrid.bind("change", function (e){
			//Note to self. the dataBound fires after the rows are returned, and dataBinding fires before. 
			var thisEventKendoGrid = e.sender;
			//console.log(e.sender);
					
			/*html layout*/
			var selectSummary = "<div class='gridSelectSummary-label'>Selection:</div>";						
			var entry_html_prefix = "<div class='gridSelectSummary-entity'>";
			var entry_html_suffix = "</div>";
			
			var selectedRow = thisEventKendoGrid.select();			
			var entry_name = thisEventKendoGrid.dataItem(selectedRow).DisplayName;
			
			// Update selectedItems Array with changes			
			var selectedItems_index = jQuery.inArray(entry_name, thisEventKendoGrid.selectedItems);			
			
			if (selectedItems_index == -1) {																
				//Empty the array if multiSelect is not enabled, as we are changing the selection.
				if (thisEventKendoGrid.isMultiSelect == false) {
					thisEventKendoGrid.selectedItems = [];
				}
				//Add new entry.
				thisEventKendoGrid.selectedItems.push(entry_name);
			}
			else {
				//Remove entry if re-clicked.
				thisEventKendoGrid.selectedItems.splice(selectedItems_index, 1);
			}			
			
			//Build selected Summary List (using selectedItems Array)
			if (thisEventKendoGrid.selectedItems.length == 0) {
				selectSummary = selectSummary + "<div class='gridSelectSummary-label'><i><font color=gray>Empty</font></i></div>"
			}
			else {
				if (thisEventKendoGrid.isMultiSelect) {
					for (var j = 0; j < thisEventKendoGrid.selectedItems.length; j++) {
						selectSummary = selectSummary + entry_html_prefix + " &nbsp;" + thisEventKendoGrid.selectedItems[j] + "&nbsp; " + entry_html_suffix;
					}
				}
				else {
					selectSummary = selectSummary + entry_html_prefix + " &nbsp;" + entry_name + "&nbsp; " + entry_html_suffix;
				}
			}
			
			/*Show selected Summary*/
			$("#gridSelectSummary" + thisEventKendoGrid.kendoGridIndex).html(selectSummary);
		});
		
		
		/*
			Sort Grid Data Alphabetically
			Code Provided from: Joivan Hedrick
		*/
        var firstColumnName = thisKendoGrid.columns[0].field;
        //var firstColumnTitle = thisKendoGrid.columns[0].title;
        var numberOfRows = thisKendoGrid.dataSource.data().length
        if (numberOfRows > 0) 
        {
            //This grid control already has data. 
            //Sort this grid, using the first column. This will sort only once, after initial page load, whether items exist in the grid or not.
            thisKendoGrid.dataSource.query({
              sort: { field: firstColumnName, dir: "asc" },
              page: 1,
              pageSize: 8,
            });
        }
        else{
            //If this request offering grid uses a previous question filter, then the initial sort won't work. Set up a one-time sort event. 
			thisKendoGrid.one("dataBound", function (e){
                //Note to self. the dataBound fires after the rows are returned, and dataBinding fires before. 
                var thisEventKendoGrid = e.sender;
                console.log(e.sender);
                
                var firstEventColumnName = thisEventKendoGrid.columns[0].field;
                var firstEventColumnTitle = thisEventKendoGrid.columns[0].title;
                //console.log("Databinding changed in event. Sorting by first column '" + firstEventColumnName + "', '" + firstEventColumnTitle + "'");
                thisEventKendoGrid.dataSource.query({
                  sort: { field: firstEventColumnName, dir: "asc" },
                  page: 1,
                  pageSize: 8,
                });
            });
        }
    }
});